# zippyshare

<badges>[![version](https://img.shields.io/pypi/v/zippyshare.svg)](https://pypi.org/project/zippyshare/)
[![license](https://img.shields.io/pypi/l/zippyshare.svg)](https://pypi.org/project/zippyshare/)
[![pyversions](https://img.shields.io/pypi/pyversions/zippyshare.svg)](https://pypi.org/project/zippyshare/)  
[![powered](https://img.shields.io/badge/Say-Thanks-ddddff.svg)](https://saythanks.io/to/foxe6)
[![donate](https://img.shields.io/badge/Donate-Paypal-0070ba.svg)](https://paypal.me/foxe6)
[![made](https://img.shields.io/badge/Made%20with-PyCharm-red.svg)](https://paypal.me/foxe6)
</badges>

<i>zippyshare complete API, CLI file manager, automatic account registration.</i>

# Hierarchy

```
zippyshare
```

# Example

## python
See `test`.